The *remove-old-dirs.ps1* Script
===========================

This PowerShell script removes any subfolder in a parent folder older than <numDays> (using last write time).

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/remove-old-dirs.ps1 [[-path] <String>] [[-numDays] <Int32>] [<CommonParameters>]

-path <String>
    Specifies the file path to the parent folder
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

-numDays <Int32>
    Specifies the number of days (1000 by default)
    
    Required?                    false
    Position?                    2
    Default value                1000
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./remove-old-dirs.ps1 C:\Temp 90

```

Notes
-----
Author: Markus Fleschutz

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Removes old directories
.DESCRIPTION
	This PowerShell script removes any subfolder in a parent folder older than <numDays> (using last write time).
.PARAMETER path
	Specifies the file path to the parent folder
.PARAMETER numDays
	Specifies the number of days (1000 by default)
.EXAMPLE
	PS> ./remove-old-dirs.ps1 C:\Temp 90
.NOTES
	Author: Markus Fleschutz
#>

param([string]$path = "", [int]$numDays = 1000)

try {
	$stopWatch = [system.diagnostics.stopwatch]::startNew()
	if ("$path" -eq "") { $path = Read-Host "Enter the file path to the parent folder" }
	if (!(Test-Path -Path "$path" -PathType container)) { throw "Given path doesn't exist - enter a valid path, please" }

	Write-Host "⏳ Removing subfolders older than $numDays days in $path..."
	$folders = Get-ChildItem -path "$path" -directory
	$numRemoved = 0
	$count = 0
	foreach ($folder in $folders) {
		[datetime]$folderDate = ($folder | Get-ItemProperty -Name LastWriteTime).LastWriteTime
		$count++
		if ($folderDate -lt (Get-Date).AddDays(-$numDays)) {
			Write-Host "($($count)) Removing old '$folder'..."
			$fullPath = $folder | Select-Object -ExpandProperty FullName
			Remove-Item -path "$fullPath" -force -recurse
			$numRemoved++
		} else {
			Write-Host "($($count)) Skipping young '$folder'..."
		}
	}
	[int]$elapsed = $stopWatch.Elapsed.TotalSeconds
	"✅ Removed $numRemoved of $count subfolders older than $numDays days in $elapsed sec"
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:52:00)*
