The *watch-commits.ps1* Script
===========================

This PowerShell script continuously lists the latest commit in a Git repository in real-time.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/watch-commits.ps1 [[-pathToRepo] <String>] [[-updateInterval] <Int32>] [[-speed] <Int32>] [<CommonParameters>]

-pathToRepo <String>
    Specifies the file path to the local Git repository.
    
    Required?                    false
    Position?                    1
    Default value                "$PWD"
    Accept pipeline input?       false
    Accept wildcard characters?  false

-updateInterval <Int32>
    
    Required?                    false
    Position?                    2
    Default value                30
    Accept pipeline input?       false
    Accept wildcard characters?  false

-speed <Int32>
    
    Required?                    false
    Position?                    3
    Default value                17
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./watch-commits.ps1
❇️ Updated general.csv by Markus Fleschutz (HEAD -> main, origin/main, origin/HEAD)
...

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Watch commits live.
.DESCRIPTION
	This PowerShell script continuously lists the latest commit in a Git repository in real-time.
.PARAMETER pathToRepo
	Specifies the file path to the local Git repository.
.EXAMPLE
	PS> ./watch-commits.ps1
	❇️ Updated general.csv by Markus Fleschutz (HEAD -> main, origin/main, origin/HEAD)
	...
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$pathToRepo = "$PWD", [int]$updateInterval = 30, [int]$speed = 17)

try {
	Write-Progress "Searching for Git executable..."
	$null = (git --version)
	if ($lastExitCode -ne "0") { throw "Can't execute 'git' - make sure Git is installed and available" }

	Write-Progress "Checking local Git repository..."
	if (-not(Test-Path "$pathToRepo" -pathType container)) { throw "Can't access directory: $pathToRepo" }
	Write-Progress -completed "Done."

	Write-Host ""
	Write-Host "TIME   COMMIT"
	Write-Host "----   ------"
	$prevLine = ""
	$tzOffset = (Get-Timezone).BaseUtcOffset.TotalSeconds
	for (;;) {
		& git -C "$pathToRepo" fetch --all --recurse-submodules=no --jobs=1 --quiet
		if ($lastExitCode -ne "0") { throw "'git fetch' failed" }

		$line = (git -C "$pathToRepo" log origin --format=format:'%at %s by %an%d' --max-count=1)
		if ($line -eq $prevLine) {
			Start-Sleep -seconds $updateInterval
			continue
		}
		$unixTimestamp = [int64]$line.Substring(0,10)
		$time = (Get-Date -day 1 -month 1 -year 1970 -hour 0 -minute 0 -second 0).AddSeconds($unixTimestamp)
		$time = $time.AddSeconds($tzOffset)
		$timeString = $time.ToString("HH:mm")
		$message = $line.Substring(11)
		& "$PSScriptRoot/write-typewriter.ps1" "$timeString  $message" $speed
		$prevLine = $line
	}
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:52:01)*
